CAAResponseRecord class

Inheritance

Constructors

CAAResponseRecord({required String name, required int ttl, required int flags, required String tag, required String value})

Properties

flags int
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
representation String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
final
ttl int
final
type String
no setteroverride
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromBytes({required String name, required int ttl, required Uint8List bytes, required int offset, required int length}) CAAResponseRecord