DNSServer class

Constructors

DNSServer({required String host, String? name, String? description, int port = 53, DNSProtocol protocol = DNSProtocol.udp, String path = '/dns-query', Map<String, String> headers = const {'Accept' : 'application/dns-message', 'Content-Type' : 'application/dns-message', 'Connection' : 'close'}})

Properties

description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>
getter/setter pair
host ↔ String
getter/setter pair
name ↔ String?
getter/setter pair
path ↔ String
getter/setter pair
port ↔ int
getter/setter pair
protocol ↔ DNSProtocol
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override
toUriString() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited